function [a, x_c, sigma, goodness]=multiple_Gaussian_fit(x, y, n_p, D)

% processing based on triple Gaussian fit
% ai, peak amplitudes
% x_ci, center locations
% sigmai, standard deviations

% model string
model=[];
for p=1:n_p
    ps=num2str(p);
    model=[model, ' + a',ps,'*exp(-(x-x_c',ps,')^2/(2*sigma',ps,'^2))'];
end
% fit model
fit_model=fittype( ...
    model, ...
    'independent', 'x', 'dependent', 'y');

opts=fitoptions( 'Method', 'NonlinearLeastSquares' );
opts.Display='off';

% initial values of parameters
a0 =ones(1,n_p)*max(y);
x_c0 =D;
sigma0 =ones(1,n_p)*mean(D)*0.05;

opts.StartPoint=[a0, sigma0, x_c0]; % Note: alphabetic order

% fit
y_data=y(:);
x_data=x(:);
[fitresult, gof]=fit(x_data, y_data, fit_model, opts);

% fit goodness
goodness=gof.rmse;

% extract fitted parameters
a=zeros(1,n_p);
x_c=zeros(1,n_p);
sigma=zeros(1,n_p);
for p=1:n_p
    ps=num2str(p);
    eval(['a(',ps,')=fitresult.a',ps,';']);
    eval(['x_c(',ps,')=fitresult.x_c',ps,';']);
    eval(['sigma(',ps,')=fitresult.sigma',ps,';']);
end

% % % % check of fit quality
% % % figure()
% % % hold on
% % % plot(fitresult, x_data, y_data)
% % % pause()

end
